EverframeWebCapture class

Browser capture is available when this package runs on Flutter web.

Constructors

EverframeWebCapture({required GlobalKey<State<StatefulWidget>> boundaryKey, required SensitiveRegionRegistry sensitiveRegions, SafeReplayBuffer? replayBuffer, void onSafeFrame(Uint8List)?, bool allowUnmarked = false})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
install() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited